package rs.master.example

import android.content.ComponentName
import android.content.Context
import android.content.DialogInterface
import android.content.ServiceConnection
import android.media.AudioManager
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.os.IBinder
import android.text.InputType
import android.util.Log
import android.view.View
import android.view.View.OnClickListener
import android.widget.Button
import android.widget.CompoundButton
import android.widget.CompoundButton.OnCheckedChangeListener
import android.widget.EditText
import android.widget.TextView
import androidx.appcompat.app.AlertDialog
import com.google.android.material.switchmaterial.SwitchMaterial
import rs.device.configurator.library.*

const val LOG_TAG = "RSMasterLibrary"

class MainActivity : AppCompatActivity(), OnCheckedChangeListener, OnClickListener {
    private lateinit var masterService: IRSMasterService
    private lateinit var audioManager: AudioManager

    private lateinit var enableWifiSwitch: SwitchMaterial
    private lateinit var enableWifiSleepPolicySwitch: SwitchMaterial
    private lateinit var enableWifiPowerSaveSwitch: SwitchMaterial
    private lateinit var enable80211rSwitch: SwitchMaterial
    private lateinit var enable80211dSwitch: SwitchMaterial
    private lateinit var enableThrottlingWifiSwitch: SwitchMaterial
    private lateinit var rssiDeltaTextView: TextView
    private lateinit var rssiThresholdTextView: TextView
    private lateinit var wifiBandTextView: TextView
    private lateinit var wifiChannels24TextView: TextView
    private lateinit var wifiChannels5TextView: TextView
    private lateinit var wifiCountryTextView: TextView
    private lateinit var addWifiButton: Button
    private lateinit var connectWifiButton: Button
    private lateinit var disconnectWifiButton: Button
    private lateinit var clearListWifiButton: Button

    private lateinit var adaptiveDisplaySwitch: SwitchMaterial
    private lateinit var autoRotateSwitch: SwitchMaterial
    private lateinit var nightLightSwitch: SwitchMaterial
    private lateinit var darkThemeSwitch: SwitchMaterial
    private lateinit var brightnessTextView: TextView
    private lateinit var displaySleepTextView: TextView
    private lateinit var fontSizeTextView: TextView
    private lateinit var densityTextView: TextView
    private lateinit var powerDisplayButton: Button

    private lateinit var enableAppButton: Button
    private lateinit var disableAppButton: Button
    private lateinit var installAppButton: Button
    private lateinit var uninstallAppButton: Button
    private lateinit var clearCacheAppButton: Button
    private lateinit var clearStorageAppButton: Button
    private lateinit var addWhiteListAppButton: Button
    private lateinit var removeWhiteListAppButton: Button
    private lateinit var clearWhiteListAppButton: Button
    private lateinit var grantPermissionAppButton: Button
    private lateinit var revokePermissionAppButton: Button
    private lateinit var openAppButton: Button
    private lateinit var killAppButton: Button

    private lateinit var modeSoundTextView: TextView
    private lateinit var callSoundTextView: TextView
    private lateinit var mediaSoundTextView: TextView
    private lateinit var ringSoundTextView: TextView
    private lateinit var alarmSoundTextView: TextView

    private lateinit var enableLocationSwitch: SwitchMaterial
    private lateinit var providerLocationTextView: TextView

    private lateinit var enableBluetoothSwitch: SwitchMaterial
    private lateinit var enableSinglePairBluetoothSwitch: SwitchMaterial
    private lateinit var clearListBluetoothButton: Button
    private lateinit var pairDeviceBluetoothButton: Button

    private lateinit var enableNFCSwitch: SwitchMaterial

    private lateinit var setAdminSecurityButton: Button
    private lateinit var revokeAdminSecurityButton: Button
    private lateinit var lockDeviceSecurityButton: Button

    private lateinit var importSettingsScannerButton: Button
    private lateinit var exportSettingsScannerButton: Button

    private lateinit var importSettingsKeyTextView: Button
    private lateinit var exportSettingsKeyTextView: Button
    private lateinit var enableRemapKeySwitch: SwitchMaterial
    private lateinit var disabledKeysTextView: TextView

    private lateinit var enableSDCardSystemSwitch: SwitchMaterial
    private lateinit var enableStatusBarSystemSwitch: SwitchMaterial
    private lateinit var enableAdbSystemSwitch: SwitchMaterial
    private lateinit var enableMobileDataSystemSwitch: SwitchMaterial
    private lateinit var enableNavigationSystemSwitch: SwitchMaterial
    private lateinit var enableSafeModeSystemSwitch: SwitchMaterial
    private lateinit var enableCameraSystemSwitch: SwitchMaterial
    private lateinit var enableAirplaneSystemSwitch: SwitchMaterial
    private lateinit var enableEthernetSystemSwitch: SwitchMaterial
    private lateinit var otaServerSystemTextView: TextView
    private lateinit var usbModeSystemTextView: TextView
    private lateinit var keyboardSystemTextView: TextView
    private lateinit var launcherSystemTextView: TextView
    private lateinit var changeLocaleSystemTextView: TextView
    private lateinit var changeSimSlotSystemTextView: TextView
    private lateinit var updateDeviceSystemButton: Button
    private lateinit var rebootDeviceSystemButton: Button
    private lateinit var shutdownDeviceSystemButton: Button
    private lateinit var wipeDeviceSystemButton: Button
    private lateinit var moveFileSystemButton: Button
    private lateinit var unknownSourceSystemButton: Button

    private lateinit var syncTimeSwitch: SwitchMaterial
    private lateinit var syncDateTimeSwitch: SwitchMaterial
    private lateinit var hourFormatTimeSwitch: SwitchMaterial
    private lateinit var unixTimeTextView: TextView
    private lateinit var ntpServerTimeTextView: TextView

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)
        audioManager = getSystemService(Context.AUDIO_SERVICE) as AudioManager
        initViews()
    }

    private fun initViews() {
        //WIFI
        enableWifiSwitch = findViewById<SwitchMaterial?>(R.id.enable_wifi).apply { setOnCheckedChangeListener(this@MainActivity) }
        enableWifiSleepPolicySwitch = findViewById<SwitchMaterial?>(R.id.enable_sleep_policy_wifi).apply { setOnCheckedChangeListener(this@MainActivity)}
        enableWifiPowerSaveSwitch = findViewById<SwitchMaterial?>(R.id.enable_power_save_wifi).apply { setOnCheckedChangeListener(this@MainActivity)}
        enable80211rSwitch = findViewById<SwitchMaterial?>(R.id.enable_80211r_wifi).apply { setOnCheckedChangeListener(this@MainActivity)}
        enable80211dSwitch = findViewById<SwitchMaterial?>(R.id.enable_80211d_wifi).apply { setOnCheckedChangeListener(this@MainActivity)}
        enableAirplaneSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_airplane_system).apply { setOnCheckedChangeListener(this@MainActivity)}
        enableEthernetSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_ethernet_system).apply { setOnCheckedChangeListener(this@MainActivity)}
        enableThrottlingWifiSwitch = findViewById<SwitchMaterial?>(R.id.enable_throttling_wifi).apply { setOnCheckedChangeListener(this@MainActivity)}
        rssiDeltaTextView = findViewById<TextView?>(R.id.rssi_delta_wifi).apply { setOnClickListener(this@MainActivity) }
        rssiThresholdTextView = findViewById<TextView?>(R.id.rssi_threshold_wifi).apply { setOnClickListener(this@MainActivity) }
        wifiBandTextView = findViewById<TextView?>(R.id.band_wifi).apply { setOnClickListener(this@MainActivity) }
        wifiChannels24TextView = findViewById<TextView?>(R.id.channels_wifi_24).apply { setOnClickListener(this@MainActivity) }
        wifiChannels5TextView = findViewById<TextView?>(R.id.channels_wifi_5).apply { setOnClickListener(this@MainActivity) }
        wifiCountryTextView = findViewById<TextView?>(R.id.country_wifi).apply { setOnClickListener(this@MainActivity) }
        addWifiButton = findViewById<Button?>(R.id.add_wifi).apply { setOnClickListener(this@MainActivity) }
        connectWifiButton = findViewById<Button?>(R.id.connect_wifi).apply { setOnClickListener(this@MainActivity) }
        disconnectWifiButton = findViewById<Button?>(R.id.disconnect_wifi).apply { setOnClickListener(this@MainActivity) }
        clearListWifiButton = findViewById<Button?>(R.id.clear_wifi_list_wifi).apply { setOnClickListener(this@MainActivity) }

        //DISPLAY
        adaptiveDisplaySwitch = findViewById<SwitchMaterial?>(R.id.enable_adaptive_display).apply { setOnCheckedChangeListener(this@MainActivity) }
        autoRotateSwitch = findViewById<SwitchMaterial?>(R.id.enable_auto_rotate_display).apply { setOnCheckedChangeListener(this@MainActivity) }
        nightLightSwitch = findViewById<SwitchMaterial?>(R.id.enable_night_light_display).apply { setOnCheckedChangeListener(this@MainActivity) }
        darkThemeSwitch = findViewById<SwitchMaterial?>(R.id.enable_dark_theme_display).apply { setOnCheckedChangeListener(this@MainActivity) }
        brightnessTextView = findViewById<TextView?>(R.id.brightness_display).apply { setOnClickListener(this@MainActivity) }
        displaySleepTextView = findViewById<TextView?>(R.id.sleep_display).apply { setOnClickListener(this@MainActivity) }
        fontSizeTextView = findViewById<TextView?>(R.id.font_size_display).apply { setOnClickListener(this@MainActivity) }
        densityTextView = findViewById<TextView?>(R.id.density_display).apply { setOnClickListener(this@MainActivity) }
        powerDisplayButton = findViewById<Button?>(R.id.power_display).apply { setOnClickListener(this@MainActivity) }

        //APP
        enableAppButton = findViewById<Button?>(R.id.enable_app).apply { setOnClickListener(this@MainActivity) }
        disableAppButton = findViewById<Button?>(R.id.disable_app).apply { setOnClickListener(this@MainActivity) }
        installAppButton = findViewById<Button?>(R.id.install_app).apply { setOnClickListener(this@MainActivity) }
        uninstallAppButton = findViewById<Button?>(R.id.uninstall_app).apply { setOnClickListener(this@MainActivity) }
        clearCacheAppButton = findViewById<Button?>(R.id.clear_cache_app).apply { setOnClickListener(this@MainActivity) }
        clearStorageAppButton = findViewById<Button?>(R.id.clear_storage_app).apply { setOnClickListener(this@MainActivity) }
        addWhiteListAppButton = findViewById<Button?>(R.id.white_list_app).apply { setOnClickListener(this@MainActivity) }
        removeWhiteListAppButton = findViewById<Button?>(R.id.remove_white_list_app).apply { setOnClickListener(this@MainActivity) }
        clearWhiteListAppButton = findViewById<Button?>(R.id.clear_white_list_app).apply { setOnClickListener(this@MainActivity) }
        grantPermissionAppButton = findViewById<Button?>(R.id.grant_permissions_app).apply { setOnClickListener(this@MainActivity) }
        revokePermissionAppButton = findViewById<Button?>(R.id.revoke_permissions_app).apply { setOnClickListener(this@MainActivity) }
        openAppButton = findViewById<Button?>(R.id.open_app).apply { setOnClickListener(this@MainActivity) }
        killAppButton = findViewById<Button?>(R.id.kill_app).apply { setOnClickListener(this@MainActivity) }

        //SOUND
        modeSoundTextView = findViewById<TextView?>(R.id.mode_sound).apply { setOnClickListener(this@MainActivity) }
        callSoundTextView = findViewById<TextView?>(R.id.call_sound).apply { setOnClickListener(this@MainActivity) }
        mediaSoundTextView = findViewById<TextView?>(R.id.media_sound).apply { setOnClickListener(this@MainActivity) }
        ringSoundTextView = findViewById<TextView?>(R.id.ring_sound).apply { setOnClickListener(this@MainActivity) }
        alarmSoundTextView = findViewById<TextView?>(R.id.alarm_sound).apply { setOnClickListener(this@MainActivity) }

        //LOCATION
        enableLocationSwitch = findViewById<SwitchMaterial?>(R.id.enable_location).apply { setOnCheckedChangeListener(this@MainActivity) }
        providerLocationTextView = findViewById<TextView?>(R.id.providers_location).apply { setOnClickListener(this@MainActivity) }

        //BLUETOOTH
        enableBluetoothSwitch = findViewById<SwitchMaterial?>(R.id.enable_bluetooth).apply { setOnCheckedChangeListener(this@MainActivity) }
        enableSinglePairBluetoothSwitch = findViewById<SwitchMaterial?>(R.id.enable_single_pair_bluetooth).apply { setOnCheckedChangeListener(this@MainActivity) }
        clearListBluetoothButton = findViewById<Button?>(R.id.clear_list_bluetooth).apply { setOnClickListener(this@MainActivity) }
        pairDeviceBluetoothButton = findViewById<Button?>(R.id.pair_device_bluetooth).apply { setOnClickListener(this@MainActivity) }

        //NFC
        enableNFCSwitch = findViewById<SwitchMaterial?>(R.id.enable_nfc).apply { setOnCheckedChangeListener(this@MainActivity) }

        //SECURITY
        setAdminSecurityButton = findViewById<Button?>(R.id.set_admin_security).apply { setOnClickListener(this@MainActivity) }
        revokeAdminSecurityButton = findViewById<Button?>(R.id.revoke_admin_security).apply { setOnClickListener(this@MainActivity) }
        lockDeviceSecurityButton = findViewById<Button?>(R.id.change_password_security).apply { setOnClickListener(this@MainActivity) }

        //SCANNER
        importSettingsScannerButton = findViewById<Button?>(R.id.import_settings_scanner).apply { setOnClickListener(this@MainActivity) }
        exportSettingsScannerButton = findViewById<Button?>(R.id.export_settings_scanner).apply { setOnClickListener(this@MainActivity) }

        //KEYS
        importSettingsKeyTextView = findViewById<Button?>(R.id.import_settings_key).apply { setOnClickListener(this@MainActivity) }
        exportSettingsKeyTextView = findViewById<Button?>(R.id.export_settings_key).apply { setOnClickListener(this@MainActivity) }
        enableRemapKeySwitch = findViewById<SwitchMaterial?>(R.id.enable_remap_key).apply { setOnCheckedChangeListener(this@MainActivity) }
        disabledKeysTextView = findViewById<TextView?>(R.id.disable_keys).apply { setOnClickListener(this@MainActivity) }

        //SYSTEM
        enableSDCardSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_sdcard_system).apply { setOnCheckedChangeListener(this@MainActivity) }
        enableStatusBarSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_status_bar_system).apply { setOnCheckedChangeListener(this@MainActivity) }
        enableAdbSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_adb_system).apply { setOnCheckedChangeListener(this@MainActivity) }
        enableMobileDataSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_mobile_data_system).apply { setOnCheckedChangeListener(this@MainActivity) }
        enableNavigationSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_navigation_system).apply { setOnCheckedChangeListener(this@MainActivity) }
        enableSafeModeSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_safe_mode_system).apply { setOnCheckedChangeListener(this@MainActivity) }
        enableCameraSystemSwitch = findViewById<SwitchMaterial?>(R.id.enable_camera_system).apply { setOnCheckedChangeListener(this@MainActivity) }
        otaServerSystemTextView = findViewById<TextView?>(R.id.ota_server_system).apply { setOnClickListener(this@MainActivity) }
        usbModeSystemTextView = findViewById<TextView?>(R.id.usb_mode_system).apply { setOnClickListener(this@MainActivity) }
        keyboardSystemTextView = findViewById<TextView?>(R.id.change_keyboard_system).apply { setOnClickListener(this@MainActivity) }
        launcherSystemTextView = findViewById<TextView?>(R.id.default_launcher_system).apply { setOnClickListener(this@MainActivity) }
        changeLocaleSystemTextView = findViewById<TextView?>(R.id.change_locale_system).apply { setOnClickListener(this@MainActivity) }
        changeSimSlotSystemTextView = findViewById<TextView?>(R.id.change_sim_slot_system).apply { setOnClickListener(this@MainActivity) }
        updateDeviceSystemButton = findViewById<Button?>(R.id.update_device_system).apply { setOnClickListener(this@MainActivity) }
        rebootDeviceSystemButton = findViewById<Button?>(R.id.reboot_device_system).apply { setOnClickListener(this@MainActivity) }
        shutdownDeviceSystemButton = findViewById<Button?>(R.id.shutdown_device_system).apply { setOnClickListener(this@MainActivity) }
        wipeDeviceSystemButton = findViewById<Button?>(R.id.wipe_device_system).apply { setOnClickListener(this@MainActivity) }
        moveFileSystemButton = findViewById<Button?>(R.id.move_file_system).apply { setOnClickListener(this@MainActivity) }
        unknownSourceSystemButton = findViewById<Button?>(R.id.unknown_source_system).apply { setOnClickListener(this@MainActivity) }

        //TIME
        syncTimeSwitch = findViewById<SwitchMaterial?>(R.id.sync_time).apply { setOnCheckedChangeListener(this@MainActivity) }
        syncDateTimeSwitch = findViewById<SwitchMaterial?>(R.id.sync_date_time).apply { setOnCheckedChangeListener(this@MainActivity) }
        hourFormatTimeSwitch = findViewById<SwitchMaterial?>(R.id.hour_format_time).apply { setOnCheckedChangeListener(this@MainActivity) }
        unixTimeTextView = findViewById<TextView?>(R.id.unix_time).apply { setOnClickListener(this@MainActivity) }
        ntpServerTimeTextView = findViewById<TextView?>(R.id.ntp_server_time).apply { setOnClickListener(this@MainActivity) }
    }

    private fun inflateViews() {
        //WIFI
        enableWifiSwitch.isChecked = masterService.isWifiEnabled
        enableWifiSleepPolicySwitch.isChecked = masterService.isWifiSleepPolicyEnabled
        enableWifiPowerSaveSwitch.isChecked = masterService.isWifiPowerSave
        enable80211rSwitch.isChecked = masterService.isWifi80211rEnabled
        enable80211dSwitch.isChecked = masterService.isWifi80211dEnabled
        enableThrottlingWifiSwitch.isChecked = masterService.isWifiThrottlingEnabled
        rssiDeltaTextView.text = masterService.wifiRSSIDifference.toString()
        rssiThresholdTextView.text = masterService.wifiRSSIThreshold.toString()
        wifiBandTextView.text = when(masterService.wifiBand) {
            1-> "2.4Ghz"
            2-> "5Ghz"
            3-> "Auto"
            else -> {"Unknown"}
        }
        val channels24 = masterService.wifiChannels24Ghz
        val channels5 = masterService.wifiChannels5Ghz
        wifiChannels24TextView.text = when(channels24) {
            "0" -> "All"
            else-> channels24
        }
        wifiChannels5TextView.text = when(channels5) {
            "0" -> "All"
            else-> channels5
        }
        wifiCountryTextView.text = masterService.wifiCountry

        //DISPLAY
        adaptiveDisplaySwitch.isChecked = masterService.isAdaptiveDisplayEnable
        autoRotateSwitch.isChecked = masterService.isAutoRotateEnable
        nightLightSwitch.isChecked = masterService.isNightLightEnable
        darkThemeSwitch.isChecked = masterService.isDarkThemeEnable
        brightnessTextView.text = masterService.brightness.toString()
        displaySleepTextView.text = masterService.displaySleep.toString()
        fontSizeTextView.text = masterService.fontSize
        densityTextView.text = masterService.densitySize

        //SOUND
        modeSoundTextView.text = audioManager.ringerMode.toString()
        callSoundTextView.text = masterService.getStreamVolume(AudioManager.STREAM_VOICE_CALL).toString()
        mediaSoundTextView.text = masterService.getStreamVolume(AudioManager.STREAM_MUSIC).toString()
        ringSoundTextView.text = masterService.getStreamVolume(AudioManager.STREAM_RING).toString()
        alarmSoundTextView.text = masterService.getStreamVolume(AudioManager.STREAM_ALARM).toString()

        //LOCATION
        enableLocationSwitch.isChecked = masterService.isLocationEnabled
        providerLocationTextView.text = masterService.locationProviders

        //BLUETOOTH
        enableBluetoothSwitch.isChecked = masterService.isBluetoothEnabled
        enableSinglePairBluetoothSwitch.isChecked = masterService.isBluetoothSinglePairing

        //NFC
        enableNFCSwitch.isChecked = masterService.isNFCEnabled

        //KEYS
        enableRemapKeySwitch.isChecked = masterService.isRemapKeyEnabled
        disabledKeysTextView.text = masterService.disabledKeys

        //SYSTEM
        enableSDCardSystemSwitch.isChecked = masterService.isSDCardEnabled
        enableStatusBarSystemSwitch.isChecked = masterService.isStatusBarEnabled
        enableAdbSystemSwitch.isChecked = masterService.isAdbEnabled
        enableMobileDataSystemSwitch.isChecked = masterService.isMobileDataEnabled
        enableNavigationSystemSwitch.isChecked = masterService.isNavigationBarEnabled
        enableSafeModeSystemSwitch.isChecked = masterService.isSafeModeEnabled
        enableCameraSystemSwitch.isChecked = masterService.isCameraApiEnabled
        otaServerSystemTextView.text = masterService.otaServer
        usbModeSystemTextView.text = masterService.usbMode
        keyboardSystemTextView.text = masterService.currentKeyboard
        launcherSystemTextView.text = masterService.defaultLauncher
        changeLocaleSystemTextView.text = masterService.currentLocale
        val simSlots = masterService.activeSIM
        changeSimSlotSystemTextView.text = if(simSlots.isNotEmpty()) simSlots.joinToString() else "No active slots"

        //TIME
        syncTimeSwitch.isChecked = masterService.syncTimeState
        syncDateTimeSwitch.isChecked = masterService.syncDateState
        ntpServerTimeTextView.text = masterService.ntpServer
        unixTimeTextView.text = System.currentTimeMillis().toString()
    }

    override fun onClick(view: View?) {
        view?.let {
            when(it.id) {
                //WIFI
                R.id.rssi_delta_wifi -> generateDialog(resources.getText(R.string.wifi_rssi_delta_label).toString(), it.id, true)
                R.id.rssi_threshold_wifi -> generateDialog(resources.getText(R.string.wifi_rssi_threshold_label).toString(), it.id, true)
                R.id.band_wifi -> generateDialog(resources.getText(R.string.wifi_band_label).toString(), it.id, true)
                R.id.channels_wifi_24 -> generateDialog(resources.getText(R.string.wifi_channels_24_label).toString(), it.id)
                R.id.channels_wifi_5 -> generateDialog(resources.getText(R.string.wifi_channels_5_label).toString(), it.id)
                R.id.country_wifi -> generateDialog(resources.getText(R.string.wifi_country_label).toString(), it.id)
                R.id.add_wifi -> generateDialog(resources.getText(R.string.add_wifi_label).toString(), it.id, false, true)
                R.id.connect_wifi -> generateDialog(resources.getText(R.string.add_wifi_label).toString(), it.id)
                R.id.disconnect_wifi -> disconnectWifi()
                R.id.clear_wifi_list_wifi -> clearWifiList(listOf("all"))
                //DISPLAY
                R.id.brightness_display -> generateDialog(resources.getText(R.string.display_brightness_label).toString(), it.id, true)
                R.id.sleep_display -> generateDialog(resources.getText(R.string.display_sleep_label).toString(), it.id, true)
                R.id.font_size_display -> generateDialog(resources.getText(R.string.display_font_size_label).toString(), it.id)
                R.id.density_display -> generateDialog(resources.getText(R.string.display_density_label).toString(), it.id)
                R.id.power_display -> setSleepScreen()
                //APP
                R.id.enable_app-> generateDialog(resources.getText(R.string.enable_app_label).toString(), it.id)
                R.id.disable_app-> generateDialog(resources.getText(R.string.disable_app_label).toString(), it.id)
                R.id.install_app-> generateDialog(resources.getText(R.string.install_app_label).toString(), it.id)
                R.id.uninstall_app-> generateDialog(resources.getText(R.string.uninstall_app_label).toString(), it.id)
                R.id.clear_cache_app-> generateDialog(resources.getText(R.string.clear_cache_app_label).toString(), it.id)
                R.id.clear_storage_app-> generateDialog(resources.getText(R.string.clear_storage_app_label).toString(), it.id)
                R.id.white_list_app-> generateDialog(resources.getText(R.string.add_white_list_app_label).toString(), it.id)
                R.id.remove_white_list_app-> generateDialog(resources.getText(R.string.remove_white_list_app_label).toString(), it.id)
                R.id.clear_white_list_app-> generateDialog(resources.getText(R.string.clear_white_list_app_label).toString(), it.id)
                R.id.grant_permissions_app-> generateDialog(resources.getText(R.string.grant_permissions_app_label).toString(), it.id)
                R.id.revoke_permissions_app-> generateDialog(resources.getText(R.string.revoke_permissions_app_label).toString(), it.id, false, true)
                R.id.open_app-> generateDialog(resources.getText(R.string.open_app_label).toString(), it.id)
                R.id.kill_app-> generateDialog(resources.getText(R.string.kill_app_label).toString(), it.id)
                //SOUND
                R.id.mode_sound-> generateDialog(resources.getText(R.string.mode_sound_label).toString(), it.id, true)
                R.id.alarm_sound-> generateDialog(resources.getText(R.string.alarm_sound_label).toString(), it.id, true)
                R.id.call_sound-> generateDialog(resources.getText(R.string.call_sound_label).toString(), it.id, true)
                R.id.media_sound-> generateDialog(resources.getText(R.string.media_sound_label).toString(), it.id, true)
                R.id.ring_sound-> generateDialog(resources.getText(R.string.ring_sound_label).toString(), it.id, true)
                //LOCATION
                R.id.providers_location-> generateDialog(resources.getText(R.string.providers_location_label).toString(), it.id, false)
                //BLUETOOTH
                R.id.clear_list_bluetooth-> clearBluetoothList(arrayListOf("all"))
                R.id.pair_device_bluetooth-> generateDialog(resources.getText(R.string.pair_device_bluetooth_label).toString(), it.id, false, true)
                //SECURITY
                R.id.set_admin_security-> generateDialog(resources.getText(R.string.set_admin_security_label).toString(), it.id)
                R.id.revoke_admin_security-> generateDialog(resources.getText(R.string.revoke_admin_security_label).toString(), it.id)
                R.id.change_password_security-> generateDialog(resources.getText(R.string.lock_security_label).toString(), it.id)
                //SCANNER
                R.id.import_settings_scanner-> generateDialog(resources.getText(R.string.import_scanner_label).toString(), it.id)
                R.id.export_settings_scanner-> generateDialog(resources.getText(R.string.export_scanner_label).toString(), it.id)
                //KEYS
                R.id.disable_keys-> generateDialog(resources.getText(R.string.disabled_keys_label).toString(), it.id)
                R.id.import_settings_key-> generateDialog(resources.getText(R.string.import_key_label).toString(), it.id)
                R.id.export_settings_key-> generateDialog(resources.getText(R.string.export_key_label).toString(), it.id)
                //SYSTEM
                R.id.ota_server_system-> generateDialog(resources.getText(R.string.ota_server_system_label).toString(), it.id)
                R.id.usb_mode_system-> generateDialog(resources.getText(R.string.usb_mode_system_label).toString(), it.id)
                R.id.change_keyboard_system-> generateDialog(resources.getText(R.string.change_keyboard_system_label).toString(), it.id)
                R.id.default_launcher_system-> generateDialog(resources.getText(R.string.default_launcher_system_label).toString(), it.id)
                R.id.update_device_system-> generateDialog(resources.getText(R.string.update_system_label).toString(), it.id)
                R.id.move_file_system-> generateDialog(resources.getText(R.string.move_file_system_label).toString(), it.id, false, true)
                R.id.reboot_device_system-> rebootDevice("userspace")
                R.id.shutdown_device_system-> shutdownDevice("userrequested")
                R.id.wipe_device_system-> wipeDevice()
                R.id.unknown_source_system-> generateDialog(resources.getText(R.string.unknown_source_system_label).toString(), it.id)
                R.id.change_locale_system-> generateDialog(resources.getText(R.string.change_locale_system_label).toString(), it.id)
                //TIME
                R.id.ntp_server_time-> generateDialog(resources.getText(R.string.ntp_server_time_label).toString(), it.id)
                R.id.unix_time-> generateDialog(resources.getText(R.string.unix_time_time_label).toString(), it.id, true)
            }
        }
    }

    override fun onResume() {
        super.onResume()
        bindService(Utils.DEVICE_SERVICE_INTENT, connection, Context.BIND_AUTO_CREATE)
    }

    override fun onPause() {
        super.onPause()
        unbindService(connection)
    }

    private val connection = object : ServiceConnection {
        override fun onServiceConnected(component: ComponentName?, binder: IBinder?) {
            Log.i(LOG_TAG, "Successful connection to the service")
            masterService = IRSMasterService.Stub.asInterface(binder)
            inflateViews()
        }

        override fun onServiceDisconnected(component: ComponentName?) {
            TODO("Not yet implemented")
        }
    }

    override fun onCheckedChanged(view: CompoundButton?, enabled: Boolean) {
        view?.let {
            when(it.id) {
                //WIFI
                R.id.enable_wifi -> if(it.isPressed)enableWifi(enabled)
                R.id.enable_sleep_policy_wifi -> if(it.isPressed)enableWifiSleepPolicy(enabled)
                R.id.enable_power_save_wifi -> if(it.isPressed)enablePowerSaveWifi(enabled)
                R.id.enable_80211r_wifi -> if(it.isPressed)enable80211r(enabled)
                R.id.enable_80211d_wifi -> if(it.isPressed)enable80211d(enabled)
                R.id.enable_throttling_wifi -> if(it.isPressed)enableWifiThrottling(enabled)
                //DISPLAY
                R.id.enable_adaptive_display -> if(it.isPressed) adaptiveBrightness(enabled)
                R.id.enable_auto_rotate_display -> if(it.isPressed) enableAutoRotateScreen(enabled)
                R.id.enable_night_light_display -> if(it.isPressed) enableNightMode(NightMode(if(enabled) 1 else 0))
                R.id.enable_dark_theme_display -> if(it.isPressed) enableDarkTheme(enabled)
                //LOCATION
                R.id.enable_location -> if(it.isPressed) enableLocation(enabled)
                //BLUETOOTH
                R.id.enable_bluetooth -> if(it.isPressed) enableBluetooth(enabled)
                R.id.enable_single_pair_bluetooth -> if(it.isPressed) setBluetoothSinglePairing(enabled)
                //NFC
                R.id.enable_nfc -> if(it.isPressed) enableNFC(enabled)
                //KEYS
                R.id.enable_remap_key -> if(it.isPressed) enableRemapKey(enabled)
                //SYSTEM
                R.id.enable_sdcard_system-> if(it.isPressed) enableSDCard(enabled)
                R.id.enable_status_bar_system-> if(it.isPressed) enableStatusBar(enabled)
                R.id.enable_adb_system-> if(it.isPressed) enableAdb(enabled)
                R.id.enable_mobile_data_system-> if(it.isPressed) enableMobileData(enabled)
                R.id.enable_navigation_system-> if(it.isPressed) hideNavigationBar(enabled)
                R.id.enable_safe_mode_system-> if(it.isPressed) setSafeModeStatus(enabled)
                R.id.enable_camera_system-> if(it.isPressed) enableCameraApi(enabled)
                R.id.enable_airplane_system-> if(it.isPressed) enableAirplane(enabled)
                R.id.enable_ethernet_system-> if(it.isPressed) enableEthernet(enabled)
                //TIME
                R.id.sync_time-> if(it.isPressed) enableSyncTime(enabled)
                R.id.sync_date_time-> if(it.isPressed) enableSyncDate(enabled)
                R.id.hour_format_time-> if(it.isPressed) set24Hours(if(enabled) 24 else 12)
            }
        }
    }

    private fun generateDialog(title: String, viewId: Int, isNumericFirst: Boolean = false, allInputVisible: Boolean = false, isNumericSecond: Boolean = false) {
        val builder = AlertDialog.Builder(this).apply {
            val view = layoutInflater.inflate(R.layout.dialog_layout, null)
            setView(view)
            setTitle(title)
            setCancelable(false)
            val firstInput = view.findViewById<EditText>(R.id.dialog_input_first)
            val secondInput = view.findViewById<EditText?>(R.id.dialog_input_second)
            if(isNumericFirst)
                firstInput.inputType = InputType.TYPE_CLASS_NUMBER
            if(allInputVisible) {
                secondInput.visibility = View.VISIBLE
                if(isNumericSecond)
                    secondInput.inputType = InputType.TYPE_CLASS_NUMBER
            }
            setNegativeButton(resources.getText(R.string.dialog_dismiss_button),
                DialogInterface.OnClickListener{ dialogInterface, _ ->  dialogInterface.dismiss()})
            setPositiveButton(getText(R.string.dialog_save_button),
                DialogInterface.OnClickListener { dialogInterface, i ->
                    updateSetting(viewId, firstInput.text.toString(), secondInput.text.toString())
                })
        }.show()
    }

    private fun updateSetting(viewId: Int, value: String, valueSecond: String = "") {
        when(viewId) {
            R.id.rssi_delta_wifi-> {
                changeRSSIDifference(value.toInt())
                rssiDeltaTextView.text = value
            }
            R.id.rssi_threshold_wifi-> {
                changeRSSIThreshold(value.toInt())
                rssiThresholdTextView.text = value
            }
            R.id.band_wifi-> {
                changeWifiFrequency(value.toInt())
                wifiBandTextView.text = value
            }
            R.id.channels_wifi_24-> {
                changeWifiChannels(2, value)
                wifiChannels24TextView.text = value
            }
            R.id.channels_wifi_5-> {
                changeWifiChannels(1, value)
                wifiChannels5TextView.text = value
            }
            R.id.country_wifi-> {
                changeWifiCountry(value)
                wifiCountryTextView.text = value
            }
            R.id.add_wifi -> {
                addWifi(Wifi(value, valueSecond))
            }
            R.id.connect_wifi -> {
                connectWifi(value)
            }
            R.id.brightness_display -> {
                screenBrightness(value.toInt())
                brightnessTextView.text = value
            }
            R.id.sleep_display -> {
                screenSleep(value.toFloat())
                displaySleepTextView.text = value
            }
            R.id.font_size_display -> {
                changeFontSize(value)
                fontSizeTextView.text = value
            }
            R.id.density_display -> {
                changeScreenDensity(value)
                densityTextView.text = value
            }
            R.id.enable_app-> {
                enableApplication(arrayListOf(value), true)
            }
            R.id.disable_app-> {
                enableApplication(arrayListOf(value), false)
            }
            R.id.install_app-> {
                installApplications(arrayListOf(value), true)
            }
            R.id.uninstall_app-> {
                deleteApplications(arrayListOf(value))
            }
            R.id.open_app-> {
                startApplication(value)
            }
            R.id.kill_app-> {
                killApplication(value)
            }
            R.id.clear_cache_app-> {
                appCacheDelete(value)
            }
            R.id.clear_storage_app-> {
                appStorageDelete(value)
            }
            R.id.white_list_app-> {
                whiteListAppsInsert(value.split(",").toList())
            }
            R.id.remove_white_list_app-> {
                whiteListAppsRemove(value.split(",").toList())
            }
            R.id.clear_white_list_app-> {
                clearWhiteListApps()
            }
            R.id.grant_permissions_app-> {
                grantPermissions(value.split(",").toList())
            }
            R.id.revoke_permissions_app-> {
                revokePermissions(value, valueSecond.split(",").toList())
            }
            R.id.mode_sound -> {
                setRingerMode(value.toInt())
                modeSoundTextView.text = value
            }
            R.id.media_sound-> {
                setVolumeLevel(AudioManager.STREAM_MUSIC, value.toInt())
                mediaSoundTextView.text = value
            }
            R.id.call_sound-> {
                setVolumeLevel(AudioManager.STREAM_VOICE_CALL, value.toInt())
                callSoundTextView.text = value
            }
            R.id.alarm_sound-> {
                setVolumeLevel(AudioManager.STREAM_ALARM, value.toInt())
                alarmSoundTextView.text = value
            }
            R.id.ring_sound-> {
                setVolumeLevel(AudioManager.STREAM_RING, value.toInt())
                ringSoundTextView.text = value
            }
            R.id.providers_location -> {
                changeLocationProviders(value.split(",").toTypedArray())
                providerLocationTextView.text = value
            }
            R.id.pair_device_bluetooth-> {
                pairDevice(value, valueSecond)
            }
            R.id.set_admin_security -> {
                setDeviceAdmin(value, true)
            }
            R.id.revoke_admin_security -> {
                setDeviceAdmin(value, false)
            }
            R.id.change_password_security -> {
                setDevicePassword(value)
            }
            R.id.import_settings_scanner -> {
                importScannerSettingsProfile("Download", value)
            }
            R.id.export_settings_scanner -> {
                exportScannerSettings(value)
            }
            R.id.disable_keys -> {
                enabledKeys(value.split(",").map { it.toInt() }.toIntArray(), false)
                disabledKeysTextView.text = value
            }
            R.id.export_settings_key-> {
                exportKeyRemapSettings(value)
            }
            R.id.import_settings_key-> {
                importKeyRemapSettings(value)
            }
            R.id.ota_server_system-> {
                setOTAServer(value)
            }
            R.id.usb_mode_system-> {
                switchUsbMode(value)
            }
            R.id.change_keyboard_system-> {
                changeKeyboard(value)
            }
            R.id.default_launcher_system-> {
                setDefaultLauncher(value)
            }
            R.id.update_device_system-> {
                updateDevice(value)
            }
            R.id.move_file_system-> {
                moveFile(value, valueSecond)
            }
            R.id.unknown_source_system-> {
                setPackageInstaller(value, true)
            }
            R.id.ntp_server_time-> {
                setNTPServer(value)
            }
            R.id.change_sim_slot_system-> {
                changeSimSlot(value.toInt())
            }
            R.id.change_locale_system-> {
                setLocale(value)
            }
            R.id.unix_time-> {
                setTime(Time(value.toLong()))
            }
        }
    }

    private fun adaptiveBrightness(enabled: Boolean) {
        val result = masterService.adaptiveBrightness(enabled)
        if(result == Const.EXECUTE_COMPLETE) {
            Log.i(LOG_TAG,"Adaptive brightness status changed: $enabled")
        } else {
            Log.e(LOG_TAG, "An error occurred while using the \"adaptiveBrightness\" function. Error \"$result\"")
        }
    }

    private fun enableStatusBar(enabled: Boolean) {
        val result = masterService.statusBarState(enabled)
        if(result == Const.EXECUTE_COMPLETE) {
            Log.i(LOG_TAG,"StatusBar status changed: $enabled")
        } else {
            Log.e(LOG_TAG, "An error occurred while using the \"statusBarState\" function. Error \"$result\"")
        }
    }

    private fun grantPermissions(listApp: List<String>) {
        when(val result = masterService.grantPermissions(listApp)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Granting permissions for the application was successful")
            Const.LIST_IS_EMPTY-> Log.w(LOG_TAG,"Function failed because list is empty")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"grantPermissions\" function. Error \"$result\"")
        }
    }

    private fun revokePermissions(app: String, permissions: List<String>) {
        when(val result = masterService.revokePermissions(app, permissions)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Revoking permissions for the application was successful")
            Const.LIST_IS_EMPTY-> Log.w(LOG_TAG,"Function failed because list is empty")
            Const.APPLICATION_NOT_INSTALLED-> Log.w(LOG_TAG,"The specified application \"$app\" is not installed")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"revokePermissions\" function. Error \"$result\"")
        }
    }

    private fun installApplications(listApp: List<String>, deleteCacheFiles: Boolean) {
        when(val result = masterService.installApplications(listApp, deleteCacheFiles)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Installation of the specified applications was successful")
            Const.LIST_IS_EMPTY-> Log.w(LOG_TAG,"Function failed because list is empty")
            Const.SERVER_ERROR-> Log.w(LOG_TAG,"Server error")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"installApplications\" function. Error \"$result\"")
        }
    }

    private fun deleteApplications(listApp: List<String>) {
        when(val result = masterService.deleteApplications(listApp)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Uninstalling the specified apps was successful")
            Const.LIST_IS_EMPTY-> Log.w(LOG_TAG,"Function failed because list is empty")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"deleteApplications\" function. Error \"$result\"")
        }
    }

    private fun clearBluetoothList(btDevices: List<String>) {
        when(val result = masterService.clearBluetoothList(btDevices)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Clearing the BT connection list was successful")
            Const.LIST_IS_EMPTY-> Log.w(LOG_TAG,"Function failed because list is empty")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"clearBluetoothList\" function. Error \"$result\"")
        }
    }

    private fun pairDevice(mac: String, password: String) {
        when(val result = masterService.pairDevice(mac, password)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Pair device successfully")
            Const.EMPTY_PAIR_PARAMS-> Log.w(LOG_TAG,"Mac device or password cannot be blank!")
            Const.PAIR_DEVICE_ERROR-> Log.w(LOG_TAG,"The specified device could not be found")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"pairDevice\" function. Error \"$result\"")
        }
    }

    private fun screenBrightness(percent: Int) {
        when(val result = masterService.screenBrightness(percent)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Display brightness set successfully")
            Const.INCORRECT_BRIGHTNESS_VALUE-> Log.w(LOG_TAG,"Wrong brightness value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"screenBrightness\" function. Error \"$result\"")
        }
    }

    private fun screenSleep(min: Float) {
        when(val result = masterService.screenSleep(min)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Display sleep set successfully")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong sleep value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"screenSleep\" function. Error \"$result\"")
        }
    }

    private fun setTime(timeConfig: Time) {
        when(val result = masterService.setTime(timeConfig)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Time set successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setTime\" function. Error \"$result\"")
        }
    }

    private fun set24Hours(formatTime: Int) {
        when(val result = masterService.set24Hours(formatTime)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Time format set successfully")
            Const.WRONG_FORMAT-> Log.i(LOG_TAG,"Incorrect time format! You must use 12 or 24")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"set24Hours\" function. Error \"$result\"")
        }
    }

    private fun setVolumeLevel(percent: Int, mode: Int) {
        when(val result = masterService.setVolumeLevel(mode, percent)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Volume set successfully")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong volume value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setVolumeLevel\" function. Error \"$result\"")
        }
    }

    private fun setRingerMode(mode: Int) {
        when(val result = masterService.setRingerMode(mode)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Ringer mode set successfully")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong mode value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setRingerMode\" function. Error \"$result\"")
        }
    }

    private fun setLocale(locale: String) {
        when(val result = masterService.setLocale(locale)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Locale set successfully")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong locale value!")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Locale value is empty!")
            Const.METHOD_NOT_FOUND-> Log.w(LOG_TAG,"The locale feature is not supported!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setLocale\" function. Error \"$result\"")
        }
    }

    private fun enableLocation(enabled: Boolean) {
        when(val result = masterService.enableLocation(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Location module changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableLocation\" function. Error \"$result\"")
        }
    }

    private fun changeLocationProviders(providers: Array<String>) {
        when(val result = masterService.changeLocationProviders(providers)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Location provider changed successfully")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong location value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeLocationProviders\" function. Error \"$result\"")
        }
    }

    private fun enableWifi(enabled: Boolean) {
        when(val result = masterService.enableWifi(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi set successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableWifi\" function. Error \"$result\"")
        }
    }

    private fun addWifi(wifiConfig: Wifi) {
        when(val result = masterService.addWifi(wifiConfig)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi added successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"addWifi\" function. Error \"$result\"")
        }
    }

    private fun connectWifi(ssid: String) {
        when(val result = masterService.connectWifi(ssid)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi connected successfully")
            Const.NOT_FIND_WIFI_SSID-> Log.w(LOG_TAG,"Could not find wifi network!")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The SSID field cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeLocationProviders\" function. Error \"$result\"")
        }
    }

    private fun disconnectWifi() {
        when(val result = masterService.disconnectWifi()) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi disconnected successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"disconnectWifi\" function. Error \"$result\"")
        }
    }

    private fun clearWifiList(wifiList: List<String>) {
        when(val result = masterService.clearWifiList(wifiList)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi list cleared successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"clearWifiList\" function. Error \"$result\"")
        }
    }

    private fun enableBluetooth(enabled: Boolean) {
        when(val result = masterService.enableBluetooth(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Bluetooth module status changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableBluetooth\" function. Error \"$result\"")
        }
    }

    private fun enableNFC(enabled: Boolean) {
        when(val result = masterService.enableNFC(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"NFC module status changed successfully")
            Const.MODULE_NOT_SUPPORTED-> Log.i(LOG_TAG,"NFC module status changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeLocationProviders\" function. Error \"$result\"")
        }
    }

    private fun enableAirplane(enabled: Boolean) {
        when(val result = masterService.enableAirplane(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Airplane status changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableAirplane\" function. Error \"$result\"")
        }
    }

    private fun enableWifiSleepPolicy(enabled: Boolean) {
        when(val result = masterService.enableWifiSleepPolicy(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi sleep policy status changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableWifiSleepPolicy\" function. Error \"$result\"")
        }
    }

    private fun enableAutoRotateScreen(enabled: Boolean) {
        when(val result = masterService.enableAutoRotateScreen(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Autorotation status changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableAutoRotateScreen\" function. Error \"$result\"")
        }
    }

    private fun enableMobileData(enabled: Boolean) {
        when(val result = masterService.enableMobileData(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"MobileData status changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableMobileData\" function. Error \"$result\"")
        }
    }

    private fun enableNightMode(nightConfig: NightMode) {
        when(val result = masterService.enableNightMode(nightConfig)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"MobileData status changed successfully")
            Const.INCORRECT_VALUE-> Log.i(LOG_TAG,"Invalid value! Value must be between 1 and 100")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableNightMode\" function. Error \"$result\"")
        }
    }

    private fun enableApplication(apps: List<String>, enabled: Boolean) {
        when(val result = masterService.enableApplication(apps, enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Applications state changed successfully")
            Const.LIST_IS_EMPTY-> Log.i(LOG_TAG,"The application list cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableApplication\" function. Error \"$result\"")
        }
    }

    private fun appCacheDelete(app: String) {
        when(val result = masterService.appCacheDelete(app)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Applications state changed successfully")
            Const.APPLICATION_NOT_INSTALLED-> Log.w(LOG_TAG,"The specified application is not installed")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the name cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"appCacheDelete\" function. Error \"$result\"")
        }
    }

    private fun appStorageDelete(app: String) {
        when(val result = masterService.appStorageDelete(app)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Applications state changed successfully")
            Const.APPLICATION_NOT_INSTALLED-> Log.w(LOG_TAG,"The specified application is not installed")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the name cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"appStorageDelete\" function. Error \"$result\"")
        }
    }

    private fun setDefaultLauncher(app: String) {
        when(val result = masterService.setDefaultLauncher(app)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Launcher changed successfully")
            Const.APPLICATION_NOT_INSTALLED-> Log.w(LOG_TAG,"The specified application is not installed")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the name cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setDefaultLauncher\" function. Error \"$result\"")
        }
    }

    private fun enableDarkTheme(enabled: Boolean) {
        when(val result = masterService.enableDarkTheme(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Theme changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableDarkTheme\" function. Error \"$result\"")
        }
    }

    private fun enableRemapKey(enabled: Boolean) {
        when(val result = masterService.enableRemapKey(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"RemapKey function changed successfully")
            Const.FUNCTION_NOT_SUPPORTED_ERROR-> Log.w(LOG_TAG,"RemapKey function not supported!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableRemapKey\" function. Error \"$result\"")
        }
    }

    private fun setDeviceAdmin(app: String, enabled: Boolean) {
        when(val result = masterService.setDeviceAdmin(app, enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"DeviceAdmin app changed successfully")
            Const.APPLICATION_NOT_INSTALLED-> Log.w(LOG_TAG,"The specified application is not installed")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the name cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setDeviceAdmin\" function. Error \"$result\"")
        }
    }

    private fun setNTPServer(server: String) {
        when(val result = masterService.setNTPServer(server)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Time server changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the server cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setNTPServer\" function. Error \"$result\"")
        }
    }

    private fun setOTAServer(server: String) {
        when(val result = masterService.setOTAServer(server)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"OTA server changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the server cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setOTAServer\" function. Error \"$result\"")
        }
    }

    private fun startApplication(app: String) {
        when(val result = masterService.startApplication(app)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Application state changed successfully")
            Const.APPLICATION_NOT_INSTALLED-> Log.w(LOG_TAG,"The specified application \"$app\" is not installed")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the name cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"startApplication\" function. Error \"$result\"")
        }
    }

    private fun killApplication(app: String) {
        when(val result = masterService.killApplication(app)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Application state changed successfully")
            Const.APPLICATION_NOT_INSTALLED-> Log.w(LOG_TAG,"The specified application \"$app\" is not installed")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the name cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"killApplication\" function. Error \"$result\"")
        }
    }

    private fun updateDevice(osPath: String) {
        when(val result = masterService.updateDevice(osPath)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Device changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the osPath cannot be empty!")
            Const.FAILED_TO_CONNECT-> Log.w(LOG_TAG,"Failed to connect to server to download OS!")
            Const.FILE_NOT_FOUND-> Log.w(LOG_TAG,"OS file could not be found!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"updateDevice\" function. Error \"$result\"")
        }
    }

    private fun changeRSSIDifference(value: Int) {
        when(val result = masterService.changeRSSIDifference(value)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"RSSI Difference changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the value cannot be empty!")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong difference value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeRSSIDifference\" function. Error \"$result\"")
        }
    }

    private fun changeRSSIThreshold(value: Int) {
        when(val result = masterService.changeRSSIThreshold(value)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"RSSI Threshold changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the value cannot be empty!")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong rssi value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeRSSIThreshold\" function. Error \"$result\"")
        }
    }

    private fun enablePowerSaveWifi(enabled: Boolean) {
        when(val result = masterService.enablePowerSaveWifi(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"WIFI Power save changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enablePowerSaveWifi\" function. Error \"$result\"")
        }
    }

    private fun changeRoamBand(value: Int) {
        when(val result = masterService.changeRoamBand(value)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Roam band changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the value cannot be empty!")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong roam value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeRoamBand\" function. Error \"$result\"")
        }
    }

    private fun enableWifiThrottling(enabled: Boolean) {
        when(val result = masterService.enableWifiThrottling(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"WIFI Throttling changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableWifiThrottling\" function. Error \"$result\"")
        }
    }

    private fun switchUsbMode(mode: String) {
        when(val result = masterService.switchUsbMode(mode)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"USB mode changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"The field with the mode cannot be empty!")
            Const.USB_MODE_NOT_FOUND-> Log.w(LOG_TAG,"USB mode not found!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"switchUsbMode\" function. Error \"$result\"")
        }
    }

    private fun enableAdb(enabled: Boolean) {
        when(val result = masterService.enableAdb(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"ADB state changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableAdb\" function. Error \"$result\"")
        }
    }

    private fun importScannerSettingsProfile(configPath: String, profileName: String) {
        when(val result = masterService.importScannerSettingsProfile(configPath, profileName)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Scanner settings changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field values cannot be empty!")
            Const.FILE_NOT_FOUND-> Log.w(LOG_TAG,"The specified file could not be found!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"importScannerSettingsProfile\" function. Error \"$result\"")
        }
    }

    private fun exportScannerSettings(profileName: String) {
        when(val result = masterService.exportScannerSettings(profileName)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Export scanner settings successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field profileName cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"exportScannerSettings\" function. Error \"$result\"")
        }
    }

    private fun moveFile(oldPath: String, newPath: String) {
        when(val result = masterService.moveFile(oldPath, newPath)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"File moved successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Fields cannot be empty!")
            Const.FILE_NOT_FOUND-> Log.w(LOG_TAG,"File could not be found!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"moveFile\" function. Error \"$result\"")
        }
    }

    private fun copyFile(oldPath: String, newPath: String) {
        when(val result = masterService.copyFile(oldPath, newPath)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"File copied successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Fields cannot be empty!")
            Const.FILE_NOT_FOUND-> Log.w(LOG_TAG,"File could not be found!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"copyFile\" function. Error \"$result\"")
        }
    }

    private fun removeFile(path: String) {
        when(val result = masterService.removeFile(path)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"File remove successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Fields cannot be empty!")
            Const.FILE_NOT_FOUND-> Log.w(LOG_TAG,"File could not be found!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"removeFile\" function. Error \"$result\"")
        }
    }

    private fun importKeyRemapSettings(configPath: String) {
        when(val result = masterService.importKeyRemapSettings(configPath)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Key settings changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field values cannot be empty!")
            Const.FILE_NOT_FOUND-> Log.w(LOG_TAG,"The specified file could not be found!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"importKeyRemapSettings\" function. Error \"$result\"")
        }
    }

    private fun exportKeyRemapSettings(path: String) {
        when(val result = masterService.exportKeyRemapSettings(path)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Export key settings successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field path cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"exportKeyRemapSettings\" function. Error \"$result\"")
        }
    }

    private fun setDevicePassword(password: String) {
        when(val result = masterService.setDevicePassword(password)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Password changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field password cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setDevicePassword\" function. Error \"$result\"")
        }
    }

    private fun changeFontSize(size: String) {
        when(val result = masterService.changeFontSize(size)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Font size changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field size cannot be empty!")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong size value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeFontSize\" function. Error \"$result\"")
        }
    }

    private fun changeScreenDensity(size: String) {
        when(val result = masterService.changeScreenDensity(size)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Density changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field size cannot be empty!")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong size value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeScreenDensity\" function. Error \"$result\"")
        }
    }

    private fun removePassword() {
        when(val result = masterService.removePassword()) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Password changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"removePassword\" function. Error \"$result\"")
        }
    }

    private fun setSleepScreen() {
        when(val result = masterService.setSleepScreen()) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Screen sleep changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setSleepScreen\" function. Error \"$result\"")
        }
    }

    private fun changeKeyboard(app: String) {
        when(val result = masterService.changeKeyboard(app)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Keyboard changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field size cannot be empty!")
            Const.KEYBOARD_NOT_FOUND-> Log.w(LOG_TAG,"The specified keyboard \"$app\" is not installed")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeKeyboard\" function. Error \"$result\"")
        }
    }

    private fun rebootDevice(mode: String) {
        when(val result = masterService.rebootDevice(mode)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Reboot device successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field mode cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"rebootDevice\" function. Error \"$result\"")
        }
    }

    private fun shutdownDevice(mode: String) {
        when(val result = masterService.shutdownDevice(mode)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Shutdown device successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field mode cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"shutdownDevice\" function. Error \"$result\"")
        }
    }

    private fun changeWifiFrequency(band: Int) {
        when(val result = masterService.changeWifiFrequency(band)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi band changed successfully")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong band value!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeWifiFrequency\" function. Error \"$result\"")
        }
    }

    private fun enabledKeys(keys: IntArray, enabled: Boolean) {
        when(val result = masterService.enabledKeys(keys, enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Keys changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field keys cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enabledKeys\" function. Error \"$result\"")
        }
    }

    private fun hideNavigationBar(enabled: Boolean) {
        when(val result = masterService.hideNavigationBar(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Navbar changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"hideNavigationBar\" function. Error \"$result\"")
        }
    }

    private fun enableSDCard(enabled: Boolean) {
        when(val result = masterService.enableSDCard(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Keys changed successfully")
            Const.FUNCTION_NOT_SUPPORTED_ERROR-> Log.w(LOG_TAG,"The sdcard feature is not supported!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableSDCard\" function. Error \"$result\"")
        }
    }

    private fun changeSimSlot(slot: Int) {
        when(val result = masterService.changeSimSlot(slot)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"SIM slot changed successfully")
            Const.SIM_SLOT_NOT_FOUND-> Log.w(LOG_TAG,"Sim slot not found!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeSimSlot\" function. Error \"$result\"")
        }
    }

    private fun changeWifiChannels(band: Int, channels: String) {
        when(val result = masterService.changeWifiChannels(band, channels)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"WIFI channels changed successfully")
            Const.VALUE_IS_EMPTY-> Log.w(LOG_TAG,"Field channels cannot be empty!")
            Const.INCORRECT_VALUE-> Log.w(LOG_TAG,"Wrong band or channels values!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeWifiChannels\" function. Error \"$result\"")
        }
    }

    private fun whiteListAppsInsert(packages: List<String>) {
        when(val result = masterService.whiteListAppsInsert(packages)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"White list packages changed successfully")
            Const.LIST_IS_EMPTY-> Log.w(LOG_TAG,"Field packages cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"whiteListAppsInsert\" function. Error \"$result\"")
        }
    }

    private fun whiteListAppsRemove(packages: List<String>) {
        when(val result = masterService.whiteListAppsRemove(packages)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"White list packages changed successfully")
            Const.LIST_IS_EMPTY-> Log.w(LOG_TAG,"Field packages cannot be empty!")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"whiteListAppsRemove\" function. Error \"$result\"")
        }
    }

    private fun clearWhiteListApps() {
        when(val result = masterService.clearWhiteListApps()) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"White list packages changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"clearWhiteListApps\" function. Error \"$result\"")
        }
    }

    private fun wipeDevice() {
        when(val result = masterService.wipeDevice()) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wipe device successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"wipeDevice\" function. Error \"$result\"")
        }
    }

    private fun enableEthernet(enabled: Boolean) {
        when(val result = masterService.enableEthernet(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Ethernet changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableEthernet\" function. Error \"$result\"")
        }
    }

    private fun setBluetoothSinglePairing(enabled: Boolean) {
        when(val result = masterService.setBluetoothSinglePairing(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Bluetooth settings changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setBluetoothSinglePairing\" function. Error \"$result\"")
        }
    }

    private fun setPackageInstaller(packageName: String, enabled: Boolean) {
        when(val result = masterService.setPackageInstaller(packageName, enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"PackageInstaller changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setPackageInstaller\" function. Error \"$result\"")
        }
    }

    private fun enableCameraApi(enabled: Boolean) {
        when(val result = masterService.enableCameraApi(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Camera state changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableCameraApi\" function. Error \"$result\"")
        }
    }

    private fun setSafeModeStatus(enabled: Boolean) {
        when(val result = masterService.setSafeModeStatus(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Safe mode state changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"setSafeModeStatus\" function. Error \"$result\"")
        }
    }

    private fun enable80211r(enabled: Boolean) {
        when(val result = masterService.enable80211r(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi settings changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enable80211r\" function. Error \"$result\"")
        }
    }

    private fun enable80211d(enabled: Boolean) {
        when(val result = masterService.enable80211d(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi settings changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enable80211d\" function. Error \"$result\"")
        }
    }

    private fun changeWifiCountry(country: String) {
        when(val result = masterService.changeWifiCountry(country)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Wifi settings changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"changeWifiCountry\" function. Error \"$result\"")
        }
    }

    private fun enableSyncTime(enabled: Boolean) {
        when(val result = masterService.setSyncTime(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Time settings changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableSyncTime\" function. Error \"$result\"")
        }
    }

    private fun enableSyncDate(enabled: Boolean) {
        when(val result = masterService.setSyncDate(enabled)) {
            Const.EXECUTE_COMPLETE-> Log.i(LOG_TAG,"Time settings changed successfully")
            else-> Log.e(LOG_TAG, "An error occurred while using the \"enableSyncDate\" function. Error \"$result\"")
        }
    }
}